==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QPickPointEvent.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds information when a segment of a point cloud is picked</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qpickpointevent.html">Qt3DRender::QPickPointEvent</a></p>
 */
public class QPickPointEvent extends io.qt.qt3d.render.QPickEvent
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPickPointEvent.class);
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpickpointevent.html#QPickPointEvent">Qt3DRender::QPickPointEvent::QPickPointEvent()</a></p>
     */
    public QPickPointEvent(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QPickPointEvent instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpickpointevent.html#QPickPointEvent">Qt3DRender::QPickPointEvent::QPickPointEvent(QPointF,QVector3D,QVector3D,float,uint,Buttons,int,int)</a></p>
     */
    public QPickPointEvent(io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int pointIndex, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers){
        super((QPrivateConstructor)null);
        initialize_native(this, position, worldIntersection, localIntersection, distance, pointIndex, button, buttons, modifiers);
    }
    
    private native static void initialize_native(QPickPointEvent instance, io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int pointIndex, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers);
    
    /**
     * <p>QPickPointEvent::pointIndex Returns the index of the picked point</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qpickpointevent.html#pointIndex">Qt3DRender::QPickPointEvent::pointIndex()const</a></p>
     */
    @io.qt.QtPropertyReader(name="pointIndex")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int pointIndex(){
        return pointIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int pointIndex_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPickPointEvent(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPickPointEvent(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPickPointEvent instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.7-sources.jar: io/qt/qt3d/render/QPickPointEvent.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds information when a segment of a point cloud is picked</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qpickpointevent.html">Qt3DRender::QPickPointEvent</a></p>
 */
public class QPickPointEvent extends io.qt.qt3d.render.QPickEvent
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPickPointEvent.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpickpointevent.html#QPickPointEvent">Qt3DRender::QPickPointEvent::QPickPointEvent()</a></p>
     */
    public QPickPointEvent(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QPickPointEvent instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpickpointevent.html#QPickPointEvent">Qt3DRender::QPickPointEvent::QPickPointEvent(QPointF,QVector3D,QVector3D,float,uint,Buttons,int,int)</a></p>
     */
    public QPickPointEvent(io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int pointIndex, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers){
        super((QPrivateConstructor)null);
        initialize_native(this, position, worldIntersection, localIntersection, distance, pointIndex, button, buttons, modifiers);
    }
    
    private native static void initialize_native(QPickPointEvent instance, io.qt.core.QPointF position, io.qt.gui.QVector3D worldIntersection, io.qt.gui.QVector3D localIntersection, float distance, int pointIndex, io.qt.qt3d.render.QPickEvent.Buttons button, int buttons, int modifiers);
    
    /**
     * <p>QPickPointEvent::pointIndex Returns the index of the picked point</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpickpointevent.html#pointIndex">Qt3DRender::QPickPointEvent::pointIndex()const</a></p>
     */
    @io.qt.QtPropertyReader(name="pointIndex")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int pointIndex(){
        return pointIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int pointIndex_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPickPointEvent(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPickPointEvent(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPickPointEvent instance, QDeclarativeConstructor constructor);
    
}
